CA10_Cl01.html
open | /cms/logout/ |
open | /admin |
type | id_username | admin
type | id_password | admin
clickAndWait | //input[@value='Iniciar sesión'] |
clickAndWait | link=Users |
clickAndWait | link=Añadir usuario |
verifyTextPresent | exact:Usuario: |
verifyTextPresent | Contraseña: |
verifyTextPresent | Contraseña (de nuevo): |
clickAndWait | _save |
verifyTextPresent | Este campo es obligatorio. |
verifyTextPresent | exact:Usuario: |
verifyTextPresent | Este campo es obligatorio. |
verifyTextPresent | Contraseña: |
verifyTextPresent | Este campo es obligatorio. |
verifyTextPresent | Contraseña (de nuevo): |
type | id_username | Pruebaca10
clickAndWait | _save |
verifyTextPresent | Este campo es obligatorio. |
verifyTextPresent | Contraseña: |
verifyTextPresent | Este campo es obligatorio. |
verifyTextPresent | Contraseña (de nuevo): |
type | id_password1 | prueba
clickAndWait | _save |
verifyTextPresent | Este campo es obligatorio. |
verifyTextPresent | Contraseña (de nuevo): |
type | id_password2 | prueba
clickAndWait | _save |
verifyTextPresent | Se añadió con éxito el user "Pruebaca10". Puede editarlo de nuevo abajo. |
clickAndWait | link=Borrar |
clickAndWait | //input[@value='Sí, estoy seguro'] |
clickAndWait | link=Terminar sesión |